Skip to contents

Get data for a single athlete by web scraping, does not require authentication.

Usage

athlind_fun(athl_num)

Arguments

athl_num

numeric athlete id used by Strava, as character string

Value

A list with elements for the athlete's information.