Skip to contents

Remove activities with no geographic data, usually manual entries

Usage

chk_nopolyline(act_data, ...)

# S3 method for class 'actframe'
chk_nopolyline(act_data, ...)

Arguments

act_data

a data.frame returned by compile_activities

...

arguments passed to or from other methods

Value

act_data with rows removed where no polylines were available, the original dataseset is returned if none were found. A warning is also returned indicating the row numbers that were removed if applicable.

Details

This function is used internally within get_elev_prof and get_heat_map to remove activities that cannot be plotted because they have no geographic information. This usually applies to activities that were manually entered.

Author

Marcus Beck

Examples

if (FALSE) { # \dontrun{
# get my activities
stoken <- httr::config(token = strava_oauth(app_name, app_client_id, app_secret, cache = TRUE))
my_acts <- get_activity_list(stoken)
act_data <- compile_activities(my_acts)
chk_nopolyline(act_data)
} # }