Skip to contents

convert a single activity list into a dataframe

Usage

compile_activity(x, columns)

Arguments

x

a list containing details of a single Strava activity

columns

a character vector of all the columns in the list of Strava activities. Produced automatically in compile_activities. Leave blank if running for a single activity list.

Value

dataframe where every column is an item from a list. Any missing columns rom the total number of columns

Details

used internally in compile_activities

Author

Daniel Padfield

Examples

if (FALSE) { # \dontrun{
stoken <- httr::config(token = strava_oauth(app_name, app_client_id, app_secret, cache = TRUE))

acts <- get_activity_list(stoken)

compile_activity(acts[1])} # }