Skip to contents

This is a wrapper function to dplyr::filter which can be applied to an actframe object

Usage

# S3 method for class 'actframe'
filter(.data, ...)

Arguments

.data

an actframe object

...

Logical predicates defined in terms of the variables in .data

Value

an actframe object

Examples

if (FALSE) { # \dontrun{
library(dplyr)

# get actframe, all activities
stoken <- httr::config(
  token = strava_oauth(
    app_name, 
    app_client_id, 
    app_secret, 
    app_scope="activity:read_all"
  )
)
my_acts <- get_activity_list(stoken)
act_data <- compile_activities(my_acts)

# mutate
act_data %>% filter(name %in% 'Morning Ride')
} # }