Skip to contents

Get detailed data of an activity, including segment efforts

Usage

get_activity(id, stoken)

Arguments

id

character vector for id of the activity

stoken

A config object created using the strava_oauth function

Value

Data from an API request.

Details

Requires authentication stoken using the strava_oauth function and a user-created API on the strava website.

The id for each activity can be viewed using results from get_activity_list.

Examples

if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id, 
  app_secret, cache = TRUE))

get_activity('75861631', stoken)
} # }