Get an activities list of the desired type (club, user)
Arguments
- stoken
A
configobject created using thestrava_oauthfunction- id
character vector for id of the activity or club if
club = TRUE, leave blank to retrieve all activities- before
date object for filtering activities before the indicated date
- after
date object for filtering activities after the indicated date
- club
logical if you want the activities of a club
Details
Requires authentication stoken using the strava_oauth function and a user-created API on the strava website. If retrieving activities using individual id values, the output list returned contains additional information from the API and the results have not been tested with the functions in this package. It is better practice to retrieve all activities (as in the example below), use compile_activities, and then filter by individual activities.
If retrieving club activities, the user for the API must be a member of the club.
Examples
if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id,
app_secret, cache = TRUE))
get_activity_list(stoken)
} # }