Skip to contents

Get basic athlete data for an athlete using an API request

Usage

get_athlete(stoken, id = NULL)

Arguments

stoken

A config object created using the strava_oauth function

id

string of athlete

Value

A list of athlete information including athlete name, location, followers, etc. as described here: https://strava.github.io/api/v3/athlete/.

Details

Requires authentication stoken using the strava_oauth function and a user-created API on the strava website.

Examples

if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id, 
  app_secret, cache = TRUE))

get_athlete(stoken, id = '2837007')
} # }