Get basic Strava data with requests that don't require pagination
Arguments
- url_
string of url for the request to the API
- stoken
A
configobject created using thestrava_oauthfunction- queries
list of additional queries or parameters
Details
Requires authentication stoken using the strava_oauth function and a user-created API on the strava website.
Examples
if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id,
app_secret, cache = TRUE))
# get basic user info
get_basic('https://strava.com/api/v3/athlete', stoken)
} # }