Get club data for a given request
Arguments
- stoken
A
configobject created using thestrava_oauthfunction- id
character vector for id of the club, defaults to authenticated club of the athlete
- request
chr string, must be "members", "activities" or
NULLfor club details
Details
Requires authentication stoken using the strava_oauth function and a user-created API on the strava website.
Examples
if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id,
app_secret, cache = TRUE))
get_club(stoken)
} # }