Get all the efforts in a segment if no queries are specified
Source:R/get_efforts_list.R
get_efforts_list.RdGet all the efforts in a segment if no queries are specified
Usage
get_efforts_list(
stoken,
id,
athlete_id = NULL,
start_date_local = NULL,
end_date_local = NULL
)Arguments
- stoken
A
configobject created using thestrava_oauthfunction- id
character string for id of the segment
- athlete_id
character string for the athlete id for filtering the results
- start_date_local
the start date for filtering the results
- end_date_local
the end date for filtering the results
Details
Requires authentication stoken using the strava_oauth function and a user-created API on the strava website.
Examples
if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id,
app_secret, cache = TRUE))
get_efforts_list(stoken, id = '229781')
} # }