Explore segments within a bounded area
Arguments
- stoken
A
configobject created using thestrava_oauthfunction- bounds
chr string representing the comma separated list of bounding box corners 'sw.lat,sw.lng,ne.lat,ne.lng' or 'south, west, north, east', see the example
- activity_type
chr string indicating activity type, "riding" or "running"
- max_cat
numeric indicating the maximum climbing category
- min_cat
numeric indicating the minimum climbing category
Details
Requires authentication stoken using the strava_oauth function and a user-created API on the strava website.
Examples
if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id,
app_secret, cache = TRUE))
bnds <- "37.821362, -122.505373, 37.842038, -122.465977"
get_explore(stoken, bnds)
} # }