Skip to contents

Retrieve a summary of the segments starred by an athlete

Usage

get_starred(stoken, id = NULL)

Arguments

stoken

A config object created using the strava_oauth function

id

character for id of the athlete, defaults to authenticated athlete

Value

Data from an API request.

Details

Requires authentication stoken using the strava_oauth function and a user-created API on the strava website.

Examples

if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id, 
  app_secret, cache = TRUE))

get_starred(stoken)
} # }