Skip to contents

Get distance and time for current month, used internally in athl_fun

Usage

monthly_fun(prsd)

Arguments

prsd

parsed input list

Value

A data frame of the current monthly distance and time for the athlete. An empty list is returned if none found.