R/recent_fun.R
recent_fun.Rd
Get last three recent activities, used internally in athl_fun
athl_fun
recent_fun(prsd)
parsed input list
A data frame of recent activities for the athlete. An empty list is returned if none found.