Set the url of activities for different activity lists
Details
This function concatenates appropriate strings so no authentication token is required. This is used internally by other functions.
Examples
if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id,
app_secret, cache = TRUE))
url_activities('2837007')
} # }