Skip to contents

Set the url of the clubs for the different requests

Usage

url_clubs(id = NULL, request = NULL)

Arguments

id

character for id of the club, defaults to authenticated club of the athlete

request

chr string, must be "members", "activities" or NULL for club details

Value

A url string.

Details

Function is used internally within get_club

Examples

url_clubs()
#> [1] "https://www.strava.com/api/v3/athlete/clubs"

url_clubs('123', request = 'members')
#> [1] "https://www.strava.com/api/v3/clubs/123/members"