Set the url for stream requests
Usage
url_streams(id, request = "activities", types = list("latlng"))Arguments
- id
character for id of the request
- request
chr string defining the stream type, must be "activities", "segment_efforts", "segments"
- types
list of chr strings with any combination of "time", "latlng", "distance", "altitude", "velocity_smooth", "heartrate", "cadence", "watts", "temp", "moving", or "grade_smooth"
Details
Function is used internally within get_streams. From the API documentation, 'streams' is the Strava term for the raw data associated with an activity.