Retrieve the laps of an activity
Arguments
- stoken
A
configobject created using thestrava_oauthfunction- id
character for id of the activity with the laps to request
Details
Requires authentication stoken using the strava_oauth function and a user-created API on the strava website.
Examples
if (FALSE) { # \dontrun{
# create authentication token
# requires user created app name, id, and secret from Strava website
stoken <- httr::config(token = strava_oauth(app_name, app_client_id,
app_secret, cache = TRUE))
get_laps(stoken, id = '351217692')
} # }