R/monthly_fun.R
monthly_fun.Rd
Get distance and time for current month, used internally in athl_fun
athl_fun
monthly_fun(prsd)
parsed input list
A data frame of the current monthly distance and time for the athlete. An empty list is returned if none found.